@@ -77,6 +77,7 @@ allocate(a) = similar(a)
 allocate(a, dim1::Integer, dims::Integer...) = similar(a, dim1, dims...)
 allocate(a, dims::Tuple) = similar(a, dims)
 allocate(a, T::Type) = similar(a, T)
+allocate(::Number, T::Type) = fill(zero(T))
 allocate(a, T::Type, dim1::Integer, dims::Integer...) = similar(a, T, dim1, dims...)
 allocate(a, T::Type, dims::Tuple) = similar(a, T, dims)
 allocate(a::AbstractArray{<:AbstractArray}) = map(allocate, a)
@@ -310,7 +311,7 @@ Check whether `X` is a valid tangent vector in the tangent space of `p` on the
 If it is not a tangent vector, an error string should be returned.
 
 By default, `check_vector` returns `nothing`, i.e. if no checks are implemented, the
-assumption is to be optimistic for tangent vectors not deriving from the [`TVector`](@ref)
+assumption is to be optimistic for tangent vectors not deriving from the [`AbstractTangentVector`](@ref)
 type.
 """
 check_vector(M::AbstractManifold, p, X; kwargs...) = nothing
@@ -635,11 +636,8 @@ end
 function _injectivity_radius(M::AbstractManifold, p, m::AbstractRetractionMethod)
     return _injectivity_radius(M, m)
 end
-function _injectivity_radius(M::AbstractManifold, m::AbstractRetractionMethod)
-    return _injectivity_radius(M)
-end
-function _injectivity_radius(M::AbstractManifold)
-    return injectivity_radius(M)
+function _injectivity_radius(M::AbstractManifold, ::AbstractRetractionMethod)
+    return _injectivity_radius(M, ExponentialRetraction())
 end
 function _injectivity_radius(M::AbstractManifold, p, ::ExponentialRetraction)
     return injectivity_radius_exp(M, p)
@@ -647,8 +645,8 @@ end
 function _injectivity_radius(M::AbstractManifold, ::ExponentialRetraction)
     return injectivity_radius_exp(M)
 end
-injectivity_radius_exp(M, p) = injectivity_radius_exp(M)
-injectivity_radius_exp(M) = injectivity_radius(M)
+injectivity_radius_exp(M::AbstractManifold, p) = injectivity_radius_exp(M)
+injectivity_radius_exp(M::AbstractManifold) = injectivity_radius(M)
 
 """
     inner(M::AbstractManifold, p, X, Y)
@@ -951,7 +949,7 @@ norm(M::AbstractManifold, p, X) = sqrt(max(real(inner(M, p, X, X)), 0))
     number_eltype(x)
 
 Numeric element type of the a nested representation of a point or a vector.
-To be used in conjuntion with [`allocate`](@ref) or [`allocate_result`](@ref).
+To be used in conjunction with [`allocate`](@ref) or [`allocate_result`](@ref).
 """
 number_eltype(x) = eltype(x)
 @inline function number_eltype(x::AbstractArray)
@@ -1098,6 +1096,14 @@ Converts a size given by `Tuple{N, M, ...}` into a tuple `(N, M, ...)`.
 """
 Base.@pure size_to_tuple(::Type{S}) where {S<:Tuple} = tuple(S.parameters...)
 
+"""
+    tangent_vector_type(::AbstractManifold, point_type::Type)
+
+Change `point_type` that is a type of points on manifold `M` to matching type for
+representing tangent vectors.
+"""
+tangent_vector_type(::AbstractManifold, point_type::Type) = point_type
+
 @doc raw"""
     Weingarten!(M, Y, p, X, V)
 
@@ -1214,14 +1220,20 @@ end
 # ------
 #
 # (a) Manifolds and general types
-export AbstractManifold, AbstractManifoldPoint, TVector, CoTVector, TFVector, CoTFVector
+export AbstractManifold,
+    AbstractManifoldPoint,
+    AbstractTangentVector,
+    AbstractCotangentVector,
+    TFVector,
+    CoTFVector
 export VectorSpaceFiber
 export TangentSpace, TangentSpaceType
 export CotangentSpace, CotangentSpaceType
 export AbstractDecoratorManifold
 export AbstractTrait, IsEmbeddedManifold, IsEmbeddedSubmanifold, IsIsometricEmbeddedManifold
 export IsExplicitDecorator
-export ValidationManifold, ValidationMPoint, ValidationTVector, ValidationCoTVector
+export ValidationManifold,
+    ValidationMPoint, ValidationTangentVector, ValidationCotangentVector
 export EmbeddedManifold
 export AbstractPowerManifold, PowerManifold
 export AbstractPowerRepresentation,
@@ -1255,7 +1267,8 @@ export AbstractRetractionMethod,
     RetractionWithKeywords,
     SasakiRetraction,
     ShootingInverseRetraction,
-    SoftmaxRetraction
+    SoftmaxRetraction,
+    StabilizedRetraction
 
 # (c) Inverse Retraction Types
 export AbstractInverseRetractionMethod,
@@ -1323,6 +1336,7 @@ export ×,
     copy,
     copyto!,
     default_approximation_method,
+    default_basis,
     default_inverse_retraction_method,
     default_retraction_method,
     default_type,
@@ -1370,8 +1384,6 @@ export ×,
     number_of_coordinates,
     number_system,
     power_dimensions,
-    parallel_transport_along,
-    parallel_transport_along!,
     parallel_transport_direction,
     parallel_transport_direction!,
     parallel_transport_to,
@@ -1394,8 +1406,6 @@ export ×,
     sectional_curvature_max,
     sectional_curvature_min,
     vector_space_dimension,
-    vector_transport_along,
-    vector_transport_along!,
     vector_transport_direction,
     vector_transport_direction!,
     vector_transport_to,
