@@ -58,9 +58,9 @@ function ManifoldsBase.check_vector(M::TestSphere, p, X; kwargs...)
     return nothing
 end
 function ManifoldsBase.exp!(M::TestSphere, q, p, X)
-    return exp!(M, q, p, X, one(number_eltype(X)))
+    return ManifoldsBase.exp_fused!(M, q, p, X, one(number_eltype(X)))
 end
-function ManifoldsBase.exp!(::TestSphere, q, p, X, t::Number)
+function ManifoldsBase.exp_fused!(::TestSphere, q, p, X, t::Number)
     θ = abs(t) * norm(X)
     if θ == 0
         copyto!(q, p)
@@ -167,7 +167,7 @@ function Random.rand!(
     return pX
 end
 ManifoldsBase.representation_size(::TestSphere{N}) where {N} = (N + 1,)
-function ManifoldsBase.retract_project!(M::TestSphere, q, p, X, t::Number)
+function ManifoldsBase.retract_project_fused!(M::TestSphere, q, p, X, t::Number)
     q .= p .+ t .* X
     project!(M, q, q)
     return q
@@ -253,11 +253,11 @@ ManifoldsBase.manifold_dimension(::ProjectionTestManifold) = 100
 struct NonManifold <: AbstractManifold{ℝ} end
 struct NonBasis <: ManifoldsBase.AbstractBasis{ℝ,TangentSpaceType} end
 struct NonMPoint <: AbstractManifoldPoint end
-struct NonTVector <: TVector end
-struct NonCoTVector <: CoTVector end
+struct NonTangentVector <: AbstractTangentVector end
+struct NonCotangentVector <: AbstractCotangentVector end
 struct NotImplementedRetraction <: AbstractRetractionMethod end
 struct NotImplementedInverseRetraction <: AbstractInverseRetractionMethod end
-*(t::Float64, X::NonTVector) = X
+*(t::Float64, X::NonTangentVector) = X
 
 struct NonBroadcastBasisThing{T}
     v::T
@@ -274,6 +274,14 @@ function ManifoldsBase.number_eltype(a::NonBroadcastBasisThing)
     return typeof(reduce(+, one(number_eltype(eti)) for eti in a.v))
 end
 
+function ManifoldsBase.allocate_on(
+    M::AbstractManifold,
+    ::TangentSpaceType,
+    T::Type{<:NonBroadcastBasisThing},
+)
+    return NonBroadcastBasisThing(similar(T.parameters[1], representation_size(M)))
+end
+
 ManifoldsBase.allocate(a::NonBroadcastBasisThing) = NonBroadcastBasisThing(allocate(a.v))
 function ManifoldsBase.allocate(a::NonBroadcastBasisThing, ::Type{T}) where {T}
     return NonBroadcastBasisThing(allocate(a.v, T))
@@ -287,22 +295,23 @@ function Base.copyto!(a::NonBroadcastBasisThing, b::NonBroadcastBasisThing)
     return a
 end
 
+
 function ManifoldsBase.log!(
     ::DefaultManifold,
-    v::NonBroadcastBasisThing,
-    x::NonBroadcastBasisThing,
-    y::NonBroadcastBasisThing,
+    X::NonBroadcastBasisThing,
+    p::NonBroadcastBasisThing,
+    q::NonBroadcastBasisThing,
 )
-    return copyto!(v, y - x)
+    return copyto!(X, q - p)
 end
 
 function ManifoldsBase.exp!(
     ::DefaultManifold,
-    y::NonBroadcastBasisThing,
-    x::NonBroadcastBasisThing,
-    v::NonBroadcastBasisThing,
+    q::NonBroadcastBasisThing,
+    p::NonBroadcastBasisThing,
+    X::NonBroadcastBasisThing,
 )
-    return copyto!(y, x + v)
+    return copyto!(q, p + X)
 end
 
 function ManifoldsBase.get_basis_orthonormal(
@@ -412,12 +421,14 @@ end
 Base.convert(::Type{DefaultPoint{T}}, v::T) where {T} = DefaultPoint(v)
 Base.eltype(p::DefaultPoint) = eltype(p.value)
 Base.length(p::DefaultPoint) = length(p.value)
-struct DefaultTVector{T} <: TVector
+struct DefaultTangentVector{T} <: AbstractTangentVector
     value::T
 end
-Base.convert(::Type{DefaultTVector{T}}, ::DefaultPoint, v::T) where {T} = DefaultTVector(v)
-Base.eltype(X::DefaultTVector) = eltype(X.value)
-function Base.fill!(X::DefaultTVector, x)
+function Base.convert(::Type{DefaultTangentVector{T}}, ::DefaultPoint, v::T) where {T}
+    return DefaultTangentVector(v)
+end
+Base.eltype(X::DefaultTangentVector) = eltype(X.value)
+function Base.fill!(X::DefaultTangentVector, x)
     fill!(X.value, x)
     return X
 end
@@ -426,24 +437,38 @@ function ManifoldsBase.allocate_result_type(
     ::typeof(log),
     ::Tuple{DefaultPoint,DefaultPoint},
 )
-    return DefaultTVector
+    return DefaultTangentVector
 end
 function ManifoldsBase.allocate_result_type(
     ::DefaultManifold,
     ::typeof(inverse_retract),
     ::Tuple{DefaultPoint,DefaultPoint},
 )
-    return DefaultTVector
+    return DefaultTangentVector
+end
+
+function ManifoldsBase.tangent_vector_type(::DefaultManifold, ::Type{DefaultPoint})
+    return DefaultTangentVector
 end
 
 ManifoldsBase.@manifold_element_forwards DefaultPoint value
-ManifoldsBase.@manifold_vector_forwards DefaultTVector value
-ManifoldsBase.@default_manifold_fallbacks ManifoldsBase.DefaultManifold DefaultPoint DefaultTVector value value
+ManifoldsBase.@manifold_vector_forwards DefaultTangentVector value
+ManifoldsBase.@default_manifold_fallbacks ManifoldsBase.DefaultManifold DefaultPoint DefaultTangentVector value value
 
 function ManifoldsBase._injectivity_radius(::DefaultManifold, ::CustomDefinedRetraction)
     return 10.0
 end
 function ManifoldsBase._retract!(
+    M::DefaultManifold,
+    q,
+    p,
+    X,
+    ::CustomDefinedKeywordRetraction;
+    kwargs...,
+)
+    return retract_custom_kw!(M, q, p, X; kwargs...)
+end
+function ManifoldsBase._retract_fused!(
     M::DefaultManifold,
     q,
     p,
@@ -452,17 +477,27 @@ function ManifoldsBase._retract!(
     ::CustomDefinedKeywordRetraction;
     kwargs...,
 )
-    return retract_custom_kw!(M, q, p, X, t; kwargs...)
+    return retract_custom_kw_fused!(M, q, p, X, t; kwargs...)
+end
+function retract_custom_kw_fused!(
+    ::DefaultManifold,
+    q::DefaultPoint,
+    p::DefaultPoint,
+    X::DefaultTangentVector,
+    t::Number;
+    scale = 2.0,
+)
+    q.value .= scale .* p.value .+ t .* X.value
+    return q
 end
 function retract_custom_kw!(
     ::DefaultManifold,
     q::DefaultPoint,
     p::DefaultPoint,
-    X::DefaultTVector,
-    t::Number;
+    X::DefaultTangentVector;
     scale = 2.0,
 )
-    q.value .= scale .* p.value .+ t .* X.value
+    q.value .= scale .* p.value .+ X.value
     return q
 end
 function ManifoldsBase._inverse_retract!(
@@ -477,7 +512,7 @@ function ManifoldsBase._inverse_retract!(
 end
 function inverse_retract_custom_kw!(
     ::DefaultManifold,
-    X::DefaultTVector,
+    X::DefaultTangentVector,
     p::DefaultPoint,
     q::DefaultPoint;
     scale = 2.0,
@@ -486,11 +521,23 @@ function inverse_retract_custom_kw!(
     return X
 end
 
-function ManifoldsBase.retract!(
+#
+# Test on layer 2 (omiting a layer 3, since we fully qualify all types here already)
+function ManifoldsBase._retract!(
     ::DefaultManifold,
     q::DefaultPoint,
     p::DefaultPoint,
-    X::DefaultTVector,
+    X::DefaultTangentVector,
+    ::CustomDefinedRetraction,
+)
+    q.value .= 2 .* p.value .+ X.value
+    return q
+end
+function ManifoldsBase._retract_fused!(
+    ::DefaultManifold,
+    q::DefaultPoint,
+    p::DefaultPoint,
+    X::DefaultTangentVector,
     t::Number,
     ::CustomDefinedRetraction,
 )
@@ -498,9 +545,9 @@ function ManifoldsBase.retract!(
     return q
 end
 
-function ManifoldsBase.inverse_retract!(
+function ManifoldsBase._inverse_retract!(
     ::DefaultManifold,
-    X::DefaultTVector,
+    X::DefaultTangentVector,
     p::DefaultPoint,
     q::DefaultPoint,
     ::CustomDefinedInverseRetraction,
@@ -513,10 +560,31 @@ struct MatrixVectorTransport{T} <: AbstractVector{T}
     m::Matrix{T}
 end
 # dummy retractions, inverse retracions for fallback tests - mutating should be enough
-ManifoldsBase.retract_polar!(::DefaultManifold, q, p, X, t::Number) = (q .= p .+ t .* X)
-ManifoldsBase.retract_project!(::DefaultManifold, q, p, X, t::Number) = (q .= p .+ t .* X)
-ManifoldsBase.retract_qr!(::DefaultManifold, q, p, X, t::Number) = (q .= p .+ t .* X)
+function ManifoldsBase.retract_polar!(::DefaultManifold, q, p, X)
+    return (q .= p .+ X)
+end
+function ManifoldsBase.retract_polar_fused!(::DefaultManifold, q, p, X, t::Number)
+    return (q .= p .+ t .* X)
+end
+function ManifoldsBase.retract_project!(::DefaultManifold, q, p, X)
+    return (q .= p .+ X)
+end
+function ManifoldsBase.retract_project_fused!(::DefaultManifold, q, p, X, t::Number)
+    return (q .= p .+ t .* X)
+end
+ManifoldsBase.retract_qr!(::DefaultManifold, q, p, X) = (q .= p .+ X)
+ManifoldsBase.retract_qr_fused!(::DefaultManifold, q, p, X, t::Number) = (q .= p .+ t .* X)
 function ManifoldsBase.retract_exp_ode!(
+    ::DefaultManifold,
+    q,
+    p,
+    X,
+    m::AbstractRetractionMethod,
+    B::ManifoldsBase.AbstractBasis,
+)
+    return (q .= p .+ X)
+end
+function ManifoldsBase.retract_exp_ode_fused!(
     ::DefaultManifold,
     q,
     p,
@@ -528,7 +596,10 @@ function ManifoldsBase.retract_exp_ode!(
     return (q .= p .+ t .* X)
 end
 
-function ManifoldsBase.retract_pade!(
+function ManifoldsBase.retract_pade!(::DefaultManifold, q, p, X, m::PadeRetraction)
+    return (q .= p .+ X)
+end
+function ManifoldsBase.retract_pade_fused!(
     ::DefaultManifold,
     q,
     p,
@@ -538,7 +609,10 @@ function ManifoldsBase.retract_pade!(
 )
     return (q .= p .+ t .* X)
 end
-function ManifoldsBase.retract_sasaki!(
+function ManifoldsBase.retract_sasaki!(::DefaultManifold, q, p, X, ::SasakiRetraction)
+    return (q .= p .+ X)
+end
+function ManifoldsBase.retract_sasaki_fused!(
     ::DefaultManifold,
     q,
     p,
@@ -548,7 +622,12 @@ function ManifoldsBase.retract_sasaki!(
 )
     return (q .= p .+ t .* X)
 end
-ManifoldsBase.retract_softmax!(::DefaultManifold, q, p, X, t::Number) = (q .= p .+ t .* X)
+function ManifoldsBase.retract_softmax!(::DefaultManifold, q, p, X)
+    return (q .= p .+ X)
+end
+function ManifoldsBase.retract_softmax_fused!(::DefaultManifold, q, p, X, t::Number)
+    return (q .= p .+ t .* X)
+end
 ManifoldsBase.get_embedding(M::DefaultManifold) = M # dummy embedding
 ManifoldsBase.inverse_retract_polar!(::DefaultManifold, Y, p, q) = (Y .= q .- p)
 ManifoldsBase.inverse_retract_project!(::DefaultManifold, Y, p, q) = (Y .= q .- p)
@@ -563,15 +642,6 @@ function ManifoldsBase.inverse_retract_nlsolve!(
 )
     return (Y .= q .- p)
 end
-function ManifoldsBase.vector_transport_along_project!(
-    ::DefaultManifold,
-    Y,
-    p,
-    X,
-    c::AbstractVector,
-)
-    return (Y .= X)
-end
 Base.getindex(x::MatrixVectorTransport, i) = x.m[:, i]
 Base.size(x::MatrixVectorTransport) = (size(x.m, 2),)
 
@@ -582,11 +652,11 @@ const TestPowerManifoldMultidimensional =
 
 export CustomDefinedInverseRetraction, CustomDefinedKeywordInverseRetraction
 export CustomDefinedKeywordRetraction, CustomDefinedRetraction, CustomUndefinedRetraction
-export DefaultPoint, DefaultTVector
+export DefaultPoint, DefaultTangentVector
 export DiagonalizingBasisProxy
 export MatrixVectorTransport
 export NonManifold, NonBasis, NonBroadcastBasisThing
-export NonMPoint, NonTVector, NonCoTVector
+export NonMPoint, NonTangentVector, NonCotangentVector
 export NotImplementedRetraction, NotImplementedInverseRetraction
 export ProjManifold, ProjectionTestManifold
 export TestSphere, TestSPD
